package com.winhc.bigdata.task.controller;

import com.alibaba.fastjson.JSONObject;
import com.aliyun.odps.OdpsException;
import com.winhc.bigdata.task.framework.odps.ExportDataCenter;
import com.winhc.bigdata.task.framework.odps.service.PullRequestRecordService;
import com.winhc.bigdata.task.framework.odps.utils.ExecOdpsSqlUtil;
import com.winhc.bigdata.task.framework.odps.vo.MaxComputeSqlInstance;
import com.winhc.bigdata.task.jobs.DynamicPersonIdUpdateJob;
import lombok.AllArgsConstructor;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.kafka.core.KafkaTemplate;
import org.springframework.kafka.support.SendResult;
import org.springframework.web.bind.annotation.*;

import java.util.concurrent.ExecutionException;

/**
 * @author: XuJiakai
 * 2021/7/6 11:48
 */
@Slf4j
@RestController
@RequestMapping("test")
@RequiredArgsConstructor
public class TestController {

    private final PullRequestRecordService pullRequestRecordService;
    private final ExportDataCenter exportDataCenter;
    private final ExecOdpsSqlUtil execOdpsSqlUtil;
    private final KafkaTemplate<String, String> kafkaTemplate;
    private final DynamicPersonIdUpdateJob dynamicPersonIdUpdateJob;

    @GetMapping("pull")
    public Object pull(String sqlId,String toMongoDbName, String pullBy) {
        return pullRequestRecordService.pull(sqlId,toMongoDbName, pullBy);
    }


    @GetMapping("test-pull")
    public Object testPull() {
        exportDataCenter.pull();
        return true;
    }

    @GetMapping("test-sql")
    public Object testSql() {
        exportDataCenter.sql();
        return true;
    }

    @GetMapping("test-export")
    public Object testExport() {
        exportDataCenter.export();
        return true;
    }

    @GetMapping("instance-status")
    public Object instanceStatus(String instanceId) {
        try {
            return MaxComputeSqlInstance.of(execOdpsSqlUtil.getInstance(instanceId));
        } catch (OdpsException e) {
            log.error(e.getMessage(), e);
            return e.getMessage();
        }
    }

    @PostMapping("push-kafka/{topic}")
    public Object push(@RequestBody String payload, @PathVariable String topic) throws ExecutionException, InterruptedException {
        return kafkaTemplate.send(topic, payload)
                .get().toString();
    }

    @PostMapping("dynamic8")
    public Object dynamic8(@RequestBody DynamicPersonIdUpdateJob.ScanParams jo) {
        dynamicPersonIdUpdateJob.scan(jo);
        return "ok";
    }
}
